summaryrefslogtreecommitdiffstats
path: root/src/H5Opublic.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Opublic.h')
-rw-r--r--src/H5Opublic.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/H5Opublic.h b/src/H5Opublic.h
index b3d0c36..c5f1b21 100644
--- a/src/H5Opublic.h
+++ b/src/H5Opublic.h
@@ -120,8 +120,12 @@ typedef struct H5O_info_t {
uint64_t shared; /* Flags to indicate message type is shared in header */
} mesg;
} hdr;
- hsize_t meta_size; /* Size of additional metadata for an object */
- /* (B-tree & heap for groups, B-tree for chunked dataset, etc.) */
+ /* btree and heap storage info for obj & attributes */
+ /* (B-tree & heap for groups, B-tree for chunked dataset, 1.8 B-tree & heap for attributes) */
+ struct {
+ H5_ih_info_t obj;
+ H5_ih_info_t attr;
+ } meta_size;
} H5O_info_t;
/* Typedef for message creation indexes */